unit UZUtils;

interface

uses
  SysUtils;

function _(str: string): string;
procedure CheckMinMax(Num: Integer; Name: string; Min, Max: integer);
function StrToIntMinMax(Num: string; Name: string; Min, Max: integer): integer;
function Parse(ParseLine: string; PartNr: integer; Delim: string): string;
function ParseStr(ParseLine: string; PartNr: integer; Delim: string; DefaultText: string): string;
function ParseInteger(ParseLine: string; PartNr: integer; Delim: string; DefaultInt: integer): integer;

implementation

function _(str: string): string;
begin
  Result := str;
end;

procedure CheckMinMax(Num: Integer; Name: string; Min, Max: integer);
begin
  if (Min > Num) or (Num > Max) then
    raise Exception.Create(Format(_('%s outside allowed range (%d - %d)'),[Name, Min, Max]));
end;

function StrToIntMinMax(Num: string; Name: string; Min, Max: integer): integer;
begin
  Result := StrToIntDef(Num, Min - 1);
  CheckMinMax(Result, Name, Min, Max);
end;

function Parse(ParseLine: string; PartNr: integer; Delim: string): string;
var
  i                 : integer;
  Start, Ende       : integer;
begin
  Start := 1;
  Ende := Length(ParseLine);
  for i := 1 to Length(ParseLine) + 1 do
  begin
    if (i > Length(ParseLine)) or ((Pos(ParseLine[i], Delim) > 0) and
      ((Delim <> ' ') or (i = Length(ParseLine)) or (ParseLine[i + 1] <> ' '))) then
    begin
      Dec(PartNr);
      if PartNr = 0 then
      begin
        Ende := i - 1;
        break;
      end;
      Start := i + 1;
    end;
  end;
  Result := Copy(ParseLine, Start, Ende - Start + 1);
end;

function ParseStr(ParseLine: string; PartNr: integer; Delim: string; DefaultText: string): string;
begin
  Result := Parse(ParseLine, PartNr, Delim);
  if Result = '' then Result := DefaultText;
end;

function ParseInteger(ParseLine: string; PartNr: integer; Delim: string; DefaultInt: integer): integer;
begin
  if ParseLine = '' then
    Result := DefaultInt
  else
    Result := StrToIntDef(ParseStr(ParseLine, PartNr, Delim, IntToStr(DefaultInt)), DefaultInt);
end;

end.
